@@ -22,26 +22,30 @@ class MovableTestCase(SIPTestCase):
         ao = AnObject(3)
         ow = ObjectWrapper()
 
+        # As of Python v3.14 we can't make assumptions about initial
+        # reference counts so we test for increases and decreases rather than
+        # absolute values.
+        ao_base_refcount = getrefcount(ao)
+
         # Test the value of the object.
         self.assertEqual(ao.getValue(), 3)
-        self.assertEqual(getrefcount(ao), 2)
+        self.assertEqual(getrefcount(ao), ao_base_refcount)
 
         # Test an empty wrapper.
         self.assertEqual(ow.getObjectValue(), -1000)
 
         # Test an non-empty wrapper.
         ow.setObject(ao)
-        self.assertEqual(getrefcount(ao), 3)
+        self.assertEqual(getrefcount(ao), ao_base_refcount + 1)
         self.assertEqual(ow.getObjectValue(), 4)
 
         # Unwrap the object and test the wrapper.
         ao2 = ow.takeObject()
-        self.assertEqual(getrefcount(ao2), 2)
         self.assertEqual(ow.getObjectValue(), -1000)
 
         # Re-test the value of the object.
         self.assertEqual(ao2.getValue(), 4)
 
         # Check that the original Python object no longer wraps the C++ object.
-        self.assertEqual(getrefcount(ao), 2)
+        self.assertEqual(getrefcount(ao), ao_base_refcount)
         self.assertRaises(RuntimeError, ao.getValue)
